@@ -848,7 +848,7 @@ class LazyUser(BaseUser):
         fake_data = {
             'username': None,
             'id': user_id,
-            'discriminator': 'BUMBA',
+            'discriminator': 0000,
             'avatar': None,
         }
 
